/*!\file KML_LinearRing.cpp
 * \brief: implementation of the kml_linearring object
 */

/*Headers:*/
/*{{{1*/
#ifdef HAVE_CONFIG_H
	#include "config.h"
#else
#error "Cannot compile with HAVE_CONFIG_H symbol! run configure first!"
#endif

#include "stdio.h"
#include <string.h>
#include "../objects.h"
#include "../../shared/shared.h"
#include "../../Container/Container.h"
#include "../../include/include.h"
/*}}}*/

/*Constructors/destructor/copy*/
/*FUNCTION KML_LinearRing::KML_LinearRing(){{{1*/
KML_LinearRing::KML_LinearRing(){

	extrude   =false;
	tessellate=false;
	strcpy(altmode   ,"clampToGround");
	ncoord    =0;
	coords    =NULL;

}
/*}}}*/
/*FUNCTION KML_LinearRing::~KML_LinearRing(){{{1*/
KML_LinearRing::~KML_LinearRing(){

	if (coords) xfree((void**)&coords);

	coords    =NULL;
	ncoord    =0;

}
/*}}}*/

/*Other*/
/*FUNCTION KML_LinearRing::Echo {{{1*/
void  KML_LinearRing::Echo(){

	bool  flag=true;

	_printf_(flag,"KML_LinearRing:\n");
	KML_Geometry::Echo();

	_printf_(flag,"       extrude: %s\n"          ,(extrude ? "true" : "false"));
	_printf_(flag,"    tessellate: %s\n"          ,(tessellate ? "true" : "false"));
	_printf_(flag,"       altmode: \"%s\"\n"      ,altmode);
	_printf_(flag,"        coords: (ncoord=%d)\n" ,ncoord);

	return;
}
/*}}}*/

/*FUNCTION KML_LinearRing::DeepEcho {{{1*/
void  KML_LinearRing::DeepEcho(){

	char  indent[81]="";

	KML_LinearRing::DeepEcho(indent);

	return;
}
/*}}}*/

/*FUNCTION KML_LinearRing::DeepEcho {{{1*/
void  KML_LinearRing::DeepEcho(char* indent){

	int   i;
	bool  flag=true;

	_printf_(flag,"%sKML_LinearRing:\n",indent);
	KML_Geometry::DeepEcho(indent);

	_printf_(flag,"%s       extrude: %s\n"          ,indent,(extrude ? "true" : "false"));
	_printf_(flag,"%s    tessellate: %s\n"          ,indent,(tessellate ? "true" : "false"));
	_printf_(flag,"%s       altmode: \"%s\"\n"      ,indent,altmode);
	_printf_(flag,"%s        coords: (ncoord=%d)\n" ,indent,ncoord);
	for (i=0; i<ncoord; i++)
		_printf_(flag,"%s                (%g,%g,%g)\n" ,indent,
				coords[i][0],coords[i][1],coords[i][2]);

	return;
}
/*}}}*/

/*FUNCTION KML_LinearRing::Write {{{1*/
void  KML_LinearRing::Write(FILE* filout,char* indent){

	int   i;

	if (this->id && strlen(this->id))
		fprintf(filout,"%s<LinearRing id=\"%s\">\n",indent,this->id);
	else
		fprintf(filout,"%s<LinearRing>\n",indent);

	KML_Geometry::Write(filout,indent);

	fprintf(filout,"%s  <extrude>%d</extrude>\n",indent,(extrude ? 1 : 0));
	fprintf(filout,"%s  <tessellate>%d</tessellate>\n",indent,(tessellate ? 1 : 0));
	fprintf(filout,"%s  <altitudeMode>%s</altitudeMode>\n",indent,altmode);
	fprintf(filout,"%s  <coordinates>\n",indent);

/*  loop over the coordinates for the linearring  */

	for (i=0; i<ncoord; i++)
		fprintf(filout,"%s    %0.16g,%0.16g,%0.16g\n",indent,
				coords[i][0],coords[i][1],coords[i][2]);

	fprintf(filout,"%s  </coordinates>\n",indent);
	fprintf(filout,"%s</LinearRing>\n",indent);

	return;
}
/*}}}*/

/*FUNCTION KML_LinearRing::Read {{{1*/
void  KML_LinearRing::Read(FILE* fid,char* kstr){


	return;
}
/*}}}*/

